@@ -15,7 +15,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.57'
+__version__ = '0.1.59'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -52,6 +52,7 @@ __info__ = {
     '2022/11/27: 0.1.55 加入 shioaji_kline, KLine OHLC',
     '2022/12/22: 0.1.56 加入 get_new_warrant_list() and add_new_issued_warrant_to_bible()',
     '2023/01/03: 0.1.57 加入 get_taifex_weight_list()',
+    '2023/01/05: 0.1.59 加入 Quote() Market()',
 }
 
 request_headers = {
@@ -838,29 +839,41 @@ def get_trade_days(date_start: Union[str, datetime.datetime] = '2018-01-01',
     return list_days
 
 
-def get_taifex_weight_list():
+# [
+#   {'symbol': 2330, 'weight': Decimal('0.26513')},
+#   {'symbol': 2464.0, 'weight': Decimal('0.000169')},
+#   {'symbol': 2317, 'weight': Decimal('0.031573')},
+#
+def get_taifex_weight_list(filename=None):
     import pandas as pd
     from decimal import Decimal
     df = pd.read_html('https://www.taifex.com.tw/cht/9/futuresQADetail')
     list_weight = []
     try:
         for x in df[0].to_dict('index').values():
-            list_weight.append({'symbol': x['證券名稱'], 'weight': Decimal(x['市值佔 大盤比重'][:-1])/100})
-            list_weight.append({'symbol': x['證券名稱.2'], 'weight': Decimal(x['市值佔 大盤比重.1'][:-1])/100})
+            list_weight.append({'symbol': str(x['證券名稱']).split(".")[0], 'weight': Decimal(x['市值佔 大盤比重'][:-1])/100})
+            list_weight.append({'symbol': str(x['證券名稱.2']).split(".")[0], 'weight': Decimal(x['市值佔 大盤比重.1'][:-1])/100})
     except Exception as e:
         pass
 
+    if filename is not None:
+        with open(filename, 'w+') as fp:
+            for x in list_weight:
+                fp.write(f'{x["symbol"]} {str(x["weight"])}\n')
+
     return list_weight
 
 
 
 
 
+
+
 if __name__ == '__main__':
     from time import sleep
 
     if True:
-        print(get_taifex_weight_list())
+        print(get_taifex_weight_list("taifex_weight.txt"))
 
     if True:
         print(price_ticks_offsets_dec(99, 6))
