@@ -7,77 +7,59 @@ from time import sleep
 import json
 from mypylib import get_trade_days
 from typing import Union
+from collections import defaultdict
 
 
+# {"AskPrice": [46.9, 46.95, 47.0, 47.2, 47.3],
+#  "AskVolume": [3, 1, 5, 9, 12],
+#  "BidPrice": [46.75, 46.6, 46.5, 46.45, 46.4],
+#  "BidVolume": [1, 24, 16, 11, 33],
+#  "Date": "2022/06/07",
+#  "Time": "09:01:41.876574"
+#  }
 class Quote(dict):
     def __init__(self, *args):
         super().__init__(*args)
+        self.Ask: Union[dict, None] = None
+        self.Bid: Union[dict, None] = None
+        self.timestamp = None
 
-        self.Ask: dict = {}
-        self.Bid: dict = {}
-
-    def AskPrice(self):
-        return super().get('AskPrice', None)
-
-    def AskVolSum(self):
-        return super().get('AskVolSum', None)
-
-    def AskVolume(self):
-        return super().get('AskVolume', None)
-
-    def BidPrice(self):
-        return super().get('BidPrice', None)
-
-    def BidVolSum(self):
-        return super().get('BidVolSum', None)
-
-    def BidVolume(self):
-        return super().get('BidVolume', None)
-
-    def Code(self):
-        return super().get('Code', None)
-
-    def Date(self):
-        return super().get('Date', None)
-
-    def DiffAskVol(self):
-        return super().get('DiffAskVol', None)
-
-    def DiffAskVolSum(self):
-        return super().get('DiffAskVolSum', None)
-
-    def DiffBidVol(self):
-        return super().get('DiffBidVol', None)
-
-    def DiffBidVolSum(self):
-        return super().get('DiffBidVolSum', None)
-
-    def FirstDerivedAskPrice(self):
-        return super().get('FirstDerivedAskPrice', None)
-
-    def FirstDerivedAskVolume(self):
-        return super().get('FirstDerivedAskVolume', None)
-
-    def FirstDerivedBidPrice(self):
-        return super().get('FirstDerivedBidPrice', None)
-
-    def FirstDerivedBidVolume(self):
-        return super().get('FirstDerivedBidVolume', None)
-
-    def TargetKindPrice(self):
-        return super().get('TargetKindPrice', None)
-
-    def Time(self):
-        return super().get('Time', None)
+    def ts(self):
+        if self.timestamp is None:
+            self.timestamp = datetime.datetime.strptime(f'{self.Date()} {self.Time()}', '%Y/%m/%d %H:%M:%S.%f')
+        return self.timestamp
 
     def Simtrade(self):
-        return super().get('Simtrade', None)
+        value = super().get('Simtrade')
+        return value[0] if isinstance(value, list) else value
 
+    def AskPrice(self):
+        return super().get('AskPrice')
+
+    def AskVolume(self):
+        return super().get('AskVolume')
+
+    def BidPrice(self):
+        return super().get('BidPrice')
+
+    def BidVolume(self):
+        return super().get('BidVolume')
+
+    def Date(self):
+        return super().get('Date')
+
+    def Time(self):
+        return super().get('Time')
+
+    # 'AskPrice': [14.4, 14.45, 14.5, 14.55, 14.6], 'AskVolume': [2239, 370, 428, 88, 316]
+    # {14.4: 2239, 14.45: 370, 14.5: 428, 14.55: 88, 14.6: 316}
     def zipAsk(self):
-        self.Ask = dict(zip(self.AskPrice(), self.AskVolume()))
+        if self.Ask is None:
+            self.Ask = defaultdict(int, dict(zip(self.AskPrice(), self.AskVolume())))
 
     def zipBid(self):
-        self.Bid = dict(zip(self.BidPrice(), self.BidVolume()))
+        if self.Bid is None:
+            self.Bid = defaultdict(int, dict(zip(self.BidPrice(), self.BidVolume())))
 
 
 # {"AmountSum": [65246500.0],
@@ -88,65 +70,44 @@ class Quote(dict):
 #  "VolSum": [156],
 #  "Volume": [3]}
 class Market(dict):
-    def Amount(self):
-        return super().get('Amount', None)
+    def __init__(self, *args):
+        super().__init__(*args)
+        self.timestamp = None
 
-    def AmountSum(self):
-        return super().get('AmountSum', None)
-
-    def AvgPrice(self):
-        return super().get('AvgPrice', None)
-
-    def Close(self):
-        return super().get('Close', None)
-
-    def Code(self):
-        return super().get('Code', None)
-
-    def Date(self):
-        return super().get('Date', None)
-
-    def DiffPrice(self):
-        return super().get('DiffPrice', None)
-
-    def DiffRate(self):
-        return super().get('DiffRate', None)
-
-    def DiffType(self):
-        return super().get('DiffType', None)
-
-    def High(self):
-        return super().get('High', None)
-
-    def Low(self):
-        return super().get('Low', None)
-
-    def Open(self):
-        return super().get('Open', None)
-
-    def TargetKindPrice(self):
-        return super().get('TargetKindPrice', None)
-
-    def TickType(self):
-        return super().get('TickType', None)
-
-    def Time(self):
-        return super().get('Time', None)
-
-    def TradeAskVolSum(self):
-        return super().get('TradeAskVolSum', None)
-
-    def TradeBidVolSum(self):
-        return super().get('TradeBidVolSum', None)
-
-    def VolSum(self):
-        return super().get('VolSum', None)
-
-    def Volume(self):
-        return super().get('Volume', None)
+    def ts(self):
+        if self.timestamp is None:
+            self.timestamp = datetime.datetime.strptime(f'{self.Date()} {self.Time()}', '%Y/%m/%d %H:%M:%S.%f')
+        return self.timestamp
 
     def Simtrade(self):
-        return super().get('Simtrade', None)
+        value = super().get('Simtrade')
+        return value[0] if isinstance(value, list) else value
+
+    def AmountSum(self):
+        value = super().get('AmountSum')
+        return value[0] if isinstance(value, list) else value
+
+    def Close(self):
+        value = super().get('Close')
+        return value[0] if isinstance(value, list) else value
+
+    def Date(self):
+        return super().get('Date')
+
+    def TickType(self):
+        value = super().get('TickType')
+        return value[0] if isinstance(value, list) else value
+
+    def Time(self):
+        return super().get('Time')
+
+    def VolSum(self):
+        value = super().get('VolSum')
+        return value[0] if isinstance(value, list) else value
+
+    def Volume(self):
+        value = super().get('Volume')
+        return value[0] if isinstance(value, list) else value
 
 
 
